% In this file the specifications of the DGPs that are used in the
% simulations are described
function[B, tShocks, Lambda, VARcoefficients, restrictionsMatrix, sampleSplit, y0, lags, sampleSplitsToEstimate, estimateSplit] = GetModelParametersForDGP(nameOfDGP)

switch nameOfDGP
    case '1a'
        B = eye(2);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [1 0; 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 0;
    case '1b'
        B = eye(2);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [2 0; 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 0;
    case '2a' % this is Table 2 t-distributed errors
        B = [1  0 ;
            0 1 ];        
        tShocks = 1;
        Lambda = 5 * eye(size(B, 1));
        Lambda = [Lambda; [1 0 ;
            0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);        
        restrictionsMatrix = [0 0 1 0];        
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 0;
    case '2b'
        B = [1  0 ;
            0 1 ];        
        tShocks = 1;
        Lambda = 5 * eye(size(B, 1));
        Lambda = [Lambda; [2 0 ;
            0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);        
        restrictionsMatrix = [0 0 1 0];        
        sampleSplit = 0.2;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 0;
    case '3a' % this is for Table 2 Chi2
        B = [1  0 ;
            0 1 ];        
        tShocks = 2;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [1 0 ;
            0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);        
        restrictionsMatrix = [0 0 1 0];        
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 0;

    case '3b'
        B = [1  0 ;
            0 1 ];        
        tShocks = 2;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [2 0 ;
            0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);        
        restrictionsMatrix = [0 0 1 0];        
        sampleSplit = 0.2;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 0;

    case '4a'
        B = eye(2);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [1 0; 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.4;
        estimateSplit = 0;

    case '4b'
        B = eye(2);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [2 0; 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.4;
        estimateSplit = 0;

    case '5a'
        B = eye(2);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [1 0; 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.3;
        estimateSplit = 0;

    case '5b'
        B = eye(2);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [2 0; 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.3;
        estimateSplit = 0;

    case '6a' % this is for Table 3
        B = [0.317487655179881,1.05981914692945;
            0.242131197251680,-0.450581021772435];
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [0.5 0; 0 1] ];
        VARcoefficients = [0.190951468888059;
            0.523705372560646;
            -0.0365191097460511;
            -0.0931227496763601;
            -0.705254146963936;
            1.21190177395125;
            0.0907268601017353;
            -0.0850547272861951;
            0.796653564304430;
            -0.276051291560303];      
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.33;
        y0 = [-0.160070802307821,3.70000000000000;
                0.197944808567918,4.50000000000000];
        lags = 2;
        sampleSplitsToEstimate = 0.33;
        estimateSplit = 0;

    case '6b' % this is for Table 3
        B = [0.317487655179881,1.05981914692945;
            0.242131197251680,-0.450581021772435];
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [0.5 0; 0 0.5] ];
        VARcoefficients = [0.190951468888059;
            0.523705372560646;
            -0.0365191097460511;
            -0.0931227496763601;
            -0.705254146963936;
            1.21190177395125;
            0.0907268601017353;
            -0.0850547272861951;
            0.796653564304430;
            -0.276051291560303];      
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.33;
        y0 = [-0.160070802307821,3.70000000000000;
                0.197944808567918,4.50000000000000];
        lags = 2;
        sampleSplitsToEstimate = 0.33;
        estimateSplit = 0;
        
    case '7a' 
        B = eye(3);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [3 0 0; 0 2 0; 0 0 1] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 0;

    case '7b'
        B = eye(3);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [3 0 0; 0 2 0; 0 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 0;

    case '8b'
        B = eye(3);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [2 0 0; 0 2 0; 0 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;       
        estimateSplit = 0;
    case '9a'
        B = eye(2);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [1 0; 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 1;
    case '9b'
        B = eye(2);
        tShocks = 0;
        Lambda = eye(size(B, 1));
        Lambda = [Lambda; [2 0; 0 2] ];
        VARcoefficients = zeros(size(B, 1), 1);
        restrictionsMatrix = [0 0 1 0];
        sampleSplit = 0.5;
        y0 = [];
        lags = 0;
        sampleSplitsToEstimate = 0.5;
        estimateSplit = 1;
    otherwise
        B = [];        
        tShocks = 0;
        Lambda = [];
        VARcoefficients = [];        
        restrictionsMatrix = [];        
        y0 = [];
        lags = 0;
end