% This is the function that is used to calculate the log likelihood of the 
% model in the structural form

function [logL] = MinimizeLikelihood(Y, T, lags, parametersToOptimise, regimes, Z, VARcoefficients)

Sigma = zeros(max(regimes) * T(1,2), T(1,2));
invertedSigma = zeros(max(regimes) * T(1,2), T(1,2));
logDetForRegime = zeros(max(regimes), 1);
LogDet = zeros(T(1,1) - lags, 1);
SSR = zeros(T(1,1) - lags, 1);

u = GetResiduals(T, Y, Z, lags, VARcoefficients);
B = parametersToOptimise(1:T(1,2), 1: T(1,2));
Lambda = eye( T(1,2));

for s = 2 : max(regimes) 
    Lambda((s-1)* T(1,2) + 1 : s* T(1,2), :) = diag(parametersToOptimise(:,  T(1,2)+s-1));
end

for s = 1: max(regimes) 
    Sigma((s-1)* T(1,2) + 1 : s* T(1,2), :)  = B * GetSigmaForRegime(Lambda, T, s) * B';
end
                
logL = 0.5*(T(1,1)-lags)*T(1,2)* log(2*pi);

for currentRegime = 1 : max(regimes)
    invertedSigma((currentRegime - 1) * T(1,2) + 1 : (currentRegime - 1) * T(1,2) + T(1,2), : ) = GetSigmaForRegime(Sigma, T, currentRegime)^-1;
    currentSigma = GetSigmaForRegime(Sigma, T, currentRegime);
    logDetForRegime(currentRegime, 1) = 0.5*log(det(currentSigma));
end

for t = 1: T(1,1) - lags
    LogDet(t , 1) = logDetForRegime(regimes(t,1));
    SSR(t , 1) = 0.5* ( u(t, :) * GetSigmaForRegime(invertedSigma, T, regimes(t,1)) * u(t, :)' );
end
 
if isreal( sum(LogDet) + sum(SSR))
    logL = logL + sum(LogDet) + sum(SSR);  
else
    logL = 10000;
end