% This is the function that initializes objects (VAR models) for simulation,
% estimates the models and extracts needed data for final output.

function [] = RunSimulation(B, Lambda, VARcoefficients, sampleLength, sampleSplit, sampleSplitMisspecified, tShocks, numberOfIterations, restrictionsMatrix, y0, DGPtoEstimate, lags, estimateSplit)
    T = [sampleLength, size(B, 1)];
	regimesTrue = getSampleSplit(sampleSplit, T);
    regimesMisspecified = getSampleSplit(sampleSplitMisspecified, T);
    startingValue = 0.5;
    lagsInSecondModel = 1;
    if (lagsInSecondModel - lags > 0)
        observationsToAdd = lagsInSecondModel - lags;
        startIndex = 1;
    else
        observationsToAdd = 0;
        startIndex = 1 + lagsInSecondModel;
    end
    
    

    for iteration = 1:numberOfIterations
        Y(:,:, iteration) = SimulateVAR(B, Lambda, VARcoefficients, T, y0, lags, regimesTrue, tShocks);
        varModel(iteration, 1) = classHVARSimple(0, 0, restrictionsMatrix, [], Y(:,:, iteration), lags, regimesMisspecified, startingValue);
        varModel1(iteration, 1) = classHVARSimple(0, 0, restrictionsMatrix, [], [zeros(observationsToAdd, size(Y, 2)); Y(startIndex: end,:, iteration)], lagsInSecondModel, regimesMisspecified, startingValue); 
        
%     This is needed to estimate the sample split in TABLE1
        if estimateSplit == 1
            counter = 1;
            modelGrid = classHVARSimple.empty;
            modelGrid4 = classHVARSimple.empty;

            regimes = getSampleSplit(0.15, T);
            firstRegimeEnds = whereFirstRegimeEnds(regimes);
            finalSearchPosition = round(T(1, 1) * 0.85);

            logLMin = 1000;
            logLMin4 = 1000;
            modelPosition = 0;
            modelPosition4 = 0;

            while firstRegimeEnds <= finalSearchPosition
                 modelGrid(counter, 1) = classHVARSimple(0, 0, restrictionsMatrix, [], Y(:,:, iteration), lags, regimes, startingValue);
                 modelGrid4(counter, 1) = classHVARSimple(0, 0, restrictionsMatrix, [], [zeros(observationsToAdd, size(Y, 2)); Y(:,:, iteration)], lagsInSecondModel, regimes, startingValue);        

                 modelGrid(counter, 1) = modelGrid(counter, 1).EstimateHVAR;
                 modelGrid4(counter, 1) = modelGrid4(counter, 1).EstimateHVAR;

                 logL = firstRegimeEnds * log(det(GetSigmaForRegime(modelGrid(counter, 1).Sigma, T, 1))) + (T(1,1) - firstRegimeEnds) *  log(det(GetSigmaForRegime(modelGrid(counter, 1).Sigma, T, 2)));
                 logL4 = firstRegimeEnds * log(det(GetSigmaForRegime(modelGrid4(counter, 1).Sigma, T, 1))) + (T(1,1) - firstRegimeEnds) *  log(det(GetSigmaForRegime(modelGrid4(counter, 1).Sigma, T, 2)));

                 if (logL < logLMin)
                     logLMin = logL;
                     modelPosition = counter;
                 end

                 if (logL4 < logLMin4)
                     logLMin4 = logL4;
                     modelPosition4 = counter;
                 end

                 regimes(firstRegimeEnds + 1) = 1;
                 firstRegimeEnds = firstRegimeEnds + 1;
                 counter = counter + 1;
            end       

            varModel(iteration, 1) = modelGrid(modelPosition, 1);
            varModel1(iteration, 1) = modelGrid4(modelPosition4, 1);
        end
    end
    
    parfor iteration = 1:numberOfIterations
         varModel(iteration, 1) = varModel(iteration, 1).EstimateHVAR;
         varModel(iteration, 1) = varModel(iteration, 1).test;

         varModel1(iteration, 1) = varModel1(iteration, 1).EstimateHVAR;
         varModel1(iteration, 1) = varModel1(iteration, 1).test;
    end
        
    for iteration = 1:numberOfIterations
        matrixB(:, :, iteration) = varModel(iteration).B;
        matrixLambda(:, :, iteration) = varModel(iteration).Lambda;
        
        regimes(:,:, iteration) = varModel(iteration).regimeRealisations;
        
        testWald(:, 1, iteration) = varModel(iteration).waldTest(:, 3); % test
        testWald(:, 2, iteration) = varModel(iteration).waldTest(:, 5); % p

        testWald(:, 3, iteration) = varModel(iteration).waldTest(:, 6); % test
        testWald(:, 4, iteration) = varModel(iteration).waldTest(:, 7); % p
        
        testWald(:, 5, iteration) = varModel(iteration).waldTest(:, 1); % s
        testWald(:, 6, iteration) = varModel(iteration).waldTest(:, 2); % r
        testWald(:, 7, iteration) = varModel(iteration).waldTest(:, 4); % DOF      
        
        testWaldNK(:, 1, iteration) = varModel(iteration).waldTestNK(:, 3); % test
        testWaldNK(:, 2, iteration) = varModel(iteration).waldTestNK(:, 5); % p
        
        matrixB4(:, :, iteration) = varModel1(iteration).B;
        matrixLambda4(:, :, iteration) = varModel1(iteration).Lambda;
        
        regimes4(:,:, iteration) = varModel1(iteration).regimeRealisations;
        
        testWald4(:, 1, iteration) = varModel1(iteration).waldTest(:, 3); % test
        testWald4(:, 2, iteration) = varModel1(iteration).waldTest(:, 5); % p

        testWald4(:, 3, iteration) = varModel1(iteration).waldTest(:, 6); % test
        testWald4(:, 4, iteration) = varModel1(iteration).waldTest(:, 7); % p
        
        testWaldNK4(:, 1, iteration) = varModel1(iteration).waldTestNK(:, 3); % test
        testWaldNK4(:, 2, iteration) = varModel1(iteration).waldTestNK(:, 5); % p
    end
    
    fileName = strcat(DGPtoEstimate, ' T', num2str(T(1,1)), ', split at ', strtrim(num2str(sampleSplitMisspecified)), '.mat');
    fprintf('Done. \n');
    save(fileName, 'testWald', 'testWaldNK', 'testWald4', 'testWaldNK4',  'matrixB', 'matrixB4', ...
                    'matrixLambda', 'matrixLambda4', 'regimes', 'regimes4');
end

function regimesTrue = getSampleSplit(sampleSplit, T)
    sampleSplit = [0 sampleSplit 1];
    for splitPosition = 1 : size(sampleSplit, 2)-1
        regimesTrue( round(T(1,1)*sampleSplit(1, splitPosition)) + 1 : round(T(1,1) * sampleSplit(1, splitPosition+1)) , 1) = splitPosition;
    end
end

function p = whereFirstRegimeEnds(regimes)
   p = sum(regimes == 1);
end

