% This is the function to simulate a VAR process that is described by input
% parameters

function[data] = SimulateVAR(B, Lambda, VARcoefficients, T,  y0, lags, regimes, tShocks)

% initial observations on Sigma and Epsilon
addionalSimulations = 0;
data = zeros(addionalSimulations+T(1,1) + lags, T(1,2));
if lags > 0
    data(1:lags, :) = y0;
end

scaling(1) = 2;
scaling(2) = 5;
denomScaling(1) = 4;
denomScaling(2) = 10;

% Simulation process, result is written in the variable Y
for t = 1:addionalSimulations+T(1,1)
    
    % the structural form errors
    structShocksVariance = GetSigmaForRegime(Lambda, T, regimes(t,1));
    for ii = 1:T(1,2)
        % specify the underlying distribution of errors
        if tShocks == 1
            structuralShocks(t, ii) = trnd(5) * sqrt(structShocksVariance(ii, ii));
        elseif tShocks == 2
            structuralShocks(t, ii) = (chi2rnd(scaling(ii)) - scaling(ii)) * sqrt(structShocksVariance(ii, ii)) / (sqrt(denomScaling(ii)));
        else
            structuralShocks(t, ii) = normrnd(0, sqrt(structShocksVariance(ii,ii)));
        end
    end
    
    % the reduced form errors
    residuals(t, :) = (B * structuralShocks(t, :)')';
    
    % calculate the vector of data
    if lags > 0
        for i = T(1,2) : T(1,2) : T(1,2)*lags
            data(t+lags, :)  = data(t+lags, :) + (GetCoefficient(VARcoefficients, T, i/T(1,2)) * data(t+lags-i/T(1,2), :)')' ;
        end
        data(t+lags, :) = data(t+lags, :) + VARcoefficients(1:T(1,2),1)' + residuals(t, :);
    else
        if (size(VARcoefficients , 1) == T(1,2))
            data(t, :) = VARcoefficients(1:T(1,2),1)' +  residuals(t, :);
        else
            data(t, :) = residuals(t, :);
        end
    end  
end
data = data(addionalSimulations+1:addionalSimulations+T(1,1) + lags, :);