disp('Oil market model');
load('oil_data.mat');
T = size(Y);
startingValue = 0.5;
lags = 3;

counter = 1;
modelGrid = classHVARSimple.empty;
        
regimes = getSampleSplit(0.15, T);
firstRegimeEnds = whereFirstRegimeEnds(regimes);
finalSearchPosition = round(T(1, 1) * 0.85);
        
logLMin = 100000;
modelPosition = 0;
        
while firstRegimeEnds <= finalSearchPosition
	modelGrid(counter, 1) = classHVARSimple(0, 0, [], [], Y, lags, regimes(lags+1:end, :), startingValue);      
             
    modelGrid(counter, 1) = modelGrid(counter, 1).EstimateHVAR;
             
    logL = firstRegimeEnds * log(det(GetSigmaForRegime(modelGrid(counter, 1).Sigma, T, 1))) + (T(1,1) - firstRegimeEnds) *  log(det(GetSigmaForRegime(modelGrid(counter, 1).Sigma, T, 2)));
             
    if (logL < logLMin)
        logLMin = logL;
        modelPosition = counter;
    end
             
    regimes(firstRegimeEnds + 1) = 1;
    firstRegimeEnds = firstRegimeEnds + 1;
    counter = counter + 1;
end

varModel = modelGrid(modelPosition, 1);
varModel = varModel.test;
varModel = varModel.CalculateStandardErrors;

disp('Relative variances:')
disp(varModel.Lambda);

disp('Std.deviation of relative variances:')
disp(varModel.standardErrorsLambda);

disp('Degrees of freedom, test statistics for relative variances and p-values:')
disp(varModel.waldTest([2, 1, 3], [4,3,5]));

shortRunRestrictionsMatrix = [0 0 0 1 0 0 0 0 0; 0 0 0 0 0 0 1 0 0; 0 0 0 0 0 0 0 1 0];
varModelRestricted = classHVAR(1, 0, shortRunRestrictionsMatrix, [], Y, lags, varModel.regimeRealisations, startingValue);
varModelRestricted = varModelRestricted.EstimateHVAR;

varModelLogL = classHVAR(0, 0, [], [], Y, lags, varModel.regimeRealisations, startingValue);
varModelLogL = varModelLogL.EstimateHVAR;

testStatistic = 2 * (varModelLogL.logL - varModelRestricted.logL);
pValue = 1 - chi2cdf(testStatistic, 3);
pValue2 = 1 - chi2cdf(testStatistic, 2);
disp('Testing restrictions:')
disp(testStatistic);
disp('p-values:')
disp(pValue);
disp(pValue2)

function regimesTrue = getSampleSplit(sampleSplit, T)
    sampleSplit = [0 sampleSplit 1];
    for splitPosition = 1 : size(sampleSplit, 2)-1
        regimesTrue( round(T(1,1)*sampleSplit(1, splitPosition)) + 1 : round(T(1,1) * sampleSplit(1, splitPosition+1)) , 1) = splitPosition;
    end
end

function p = whereFirstRegimeEnds(regimes)
   p = sum(regimes == 1);
end